from typing import Literal

LineClamp = Literal[
    '1',
    '2',
    '3',
    '4',
    '5',
    '6',
    'none',
]
